# Shortcut Functions for Text Operations

## Install

    pip install invisibleroads-macros-text

## Test

    git clone https://github.com/invisibleroads/invisibleroads-macros-text
    cd invisibleroads-macros-text
    pip install -e .[test]
    pytest --cov=invisibleroads_macros_text --cov-report term-missing tests
